#include "DirectInput.h"

CDirectInputFramework::CDirectInputFramework(){}

CDirectInputFramework::~CDirectInputFramework(){}

void CDirectInputFramework::Poll()
{
	for(int i = 0; i < 256; ++i)
	{
		m_PrevKeyboardState[i] = m_KeyboardState[i];
	}
	HR(m_pKeyboard->GetDeviceState(sizeof(m_KeyboardState), (LPVOID)&m_KeyboardState));
	HR(m_pMouse->GetDeviceState(sizeof(DIMOUSESTATE2), &m_MouseState));

}

bool CDirectInputFramework::KeyDown(unsigned char key)
{
	if(m_KeyboardState[key] & 0x80)
		return true;
	else
		return false;
}

bool CDirectInputFramework::WasKeyDown(unsigned char key)
{
	if(m_PrevKeyboardState[key] & 0x80)
		return true;
	else
		return false;
}

bool CDirectInputFramework::MouseButtonDown(int button)
{
	if(m_MouseState.rgbButtons[button] & 0x80)
		return true;
	else
		return false;
}

float CDirectInputFramework::MouseDX()
{
	return (float)m_MouseState.lX;
}

float CDirectInputFramework::MouseDY()
{
	return (float)m_MouseState.lY;
}

void CDirectInputFramework::Init(HWND hWnd, HINSTANCE hInst)
{
	HR(DirectInput8Create(hInst, DIRECTINPUT_VERSION, IID_IDirectInput8, (void**)&m_pInput, NULL));

	HR(m_pInput->CreateDevice(GUID_SysKeyboard, &m_pKeyboard, NULL));
	HR(m_pInput->CreateDevice(GUID_SysMouse, &m_pMouse, NULL));

	//Data formats
	HR(m_pKeyboard->SetDataFormat(&c_dfDIKeyboard));
	HR(m_pMouse->SetDataFormat(&c_dfDIMouse2));

	//Cooperative Levels
	HR(m_pKeyboard->SetCooperativeLevel(hWnd, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE));
	HR(m_pMouse->SetCooperativeLevel(hWnd, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE));

	//Aquire Devices
	HR(m_pKeyboard->Acquire());
	HR(m_pMouse->Acquire());

	for(int i = 0; i < 256; ++i)
	{
		m_PrevKeyboardState[i] = false;
	}
}

void CDirectInputFramework::Shutdown()
{
	m_pMouse->Unacquire();
	m_pKeyboard->Unacquire();
	SAFE_RELEASE(m_pMouse);
	SAFE_RELEASE(m_pKeyboard);
	SAFE_RELEASE(m_pInput);
}