#pragma once
#define DIRECTINPUT_VERSION 0x0800
#include <dinput.h>
#include <DxErr.h>
#pragma comment(lib, "dxerr.lib")
// Macro to release COM objects fast and safely
#define SAFE_RELEASE(x) if(x){x->Release(); x = 0;}

// HRESULT macro that prints an error window
#ifndef HR
#define HR(x)												\
		{                                                   \
		HRESULT hr = x;									    \
		if(FAILED(hr))									    \
			{                                               \
			DXTraceA(__FILE__, __LINE__, hr, #x, TRUE);	    \
			}                                               \
		}                                                   
#endif

class CDirectInputFramework
{
	/////////////////////////////////////////////////////////////////////////
	//Direct Input Variables
	/////////////////////////////////////////////////////////////////////////
	IDirectInput8*				m_pInput;					//DirectInput interface
	IDirectInputDevice8*		m_pKeyboard;				//Keyboard Interface
	IDirectInputDevice8*		m_pMouse;					//Mouse Interface
	char						m_KeyboardState[256];		//Keyboard state/buffer
	char						m_PrevKeyboardState[256];	//Previous Keyboard state
	DIMOUSESTATE2				m_MouseState;				//Mouse State

public:
	CDirectInputFramework();
	~CDirectInputFramework();

	//////////////////////////////////////////////////////////////////////////
	// Name:		Poll
	// Parameters:	none
	// Return:		none
	// Description:	Refreshes input data (gets new data from devices)
	//////////////////////////////////////////////////////////////////////////
	void Poll();

	//////////////////////////////////////////////////////////////////////////
	// Name:		KeyDown
	// Parameters:	unsigned char key - The Key being tested
	// Return:		bool
	// Description:	Tests whether a key is being pressed. Returns true if so.
	//////////////////////////////////////////////////////////////////////////
	bool KeyDown(unsigned char key);

	//////////////////////////////////////////////////////////////////////////
	// Name:		WasKeyDown
	// Parameters:	unsigned char key - The Key being tested
	// Return:		bool
	// Description:	Tests whether a key was down last update. Returns true if so.
	//////////////////////////////////////////////////////////////////////////
	bool WasKeyDown(unsigned char key);

	//////////////////////////////////////////////////////////////////////////
	// Name:		MouseButtonDown
	// Parameters:	int button - The index for the button being pressed.
	// Return:		bool
	// Description:	Tests whether a mouse button is being pressed. Returns true if so.
	//////////////////////////////////////////////////////////////////////////
	bool MouseButtonDown(int button);

	//////////////////////////////////////////////////////////////////////////
	// Name:		MouseDX
	// Parameters:	none
	// Return:		float
	// Description:	Returns the distance the mouse has moved along the X axis
	//////////////////////////////////////////////////////////////////////////
	float MouseDX();

	//////////////////////////////////////////////////////////////////////////
	// Name:		MouseDY
	// Parameters:	none
	// Return:		float
	// Description:	Returns the distance the mouse has moved along the Y axis
	//////////////////////////////////////////////////////////////////////////
	float MouseDY();
		
	//////////////////////////////////////////////////////////////////////////
	// Name:		Init
	// Parameters:	HINSTANCE hInst - Handle to the instance
	//				HWND hWnd - Handle to the window
	// Return:		none
	// Description:	Creates DirectInput object, Mouse and keyboard objects,
	//				and sets up mouse and keyboard for input.
	//////////////////////////////////////////////////////////////////////////
	void Init(HWND hWnd, HINSTANCE hInst);

	
	//////////////////////////////////////////////////////////////////////////
	// Name:		Shutdown
	// Parameters:	none
	// Return:		none
	// Description:	Releases mouse and keyboard objects
	//////////////////////////////////////////////////////////////////////////
	void Shutdown();


};