#pragma once

	//////////////////////////////////////////////////////////////////////////
	// Name:		Axis
	// Description:	Used to denote which axis a collision reflects about.
	//				Main purpose is to restrict values being passed to contact function
	//////////////////////////////////////////////////////////////////////////
	enum Axis{X, Y, Z};

	//////////////////////////////////////////////////////////////////////////
	// Name:		MenuState
	// Description:	Stores the current state of the menu. Used for switching
	//				between main menu and submenus
	//////////////////////////////////////////////////////////////////////////
	enum MenuState{MainMenu, OptionsMenu, Credits, GameOver, GameRunning, MenuPaused, ExitingGame};
	
	//////////////////////////////////////////////////////////////////////////
	// Name:		GameState
	// Description:	Stores the current state of the game. Used for switching
	//				between Intro video, Menu, and main gameplay.
	//////////////////////////////////////////////////////////////////////////
	enum GameState{Intro, Menu, Playing, Quit};

	//////////////////////////////////////////////////////////////////////////
	// Name:		MenuSelect
	// Description:	Stores the current select menu option. Used to determine
	//				which buttons should be rendered, what state (selected?)
	//				and to determine which button is selected when hitting enter
	//////////////////////////////////////////////////////////////////////////
	enum MenuSelect{None, PlayButton, OptionsButton, CreditsButton, MainButton, QuitButton, FullscreenButton};

	//////////////////////////////////////////////////////////////////////////
	// Name:		Player
	// Description:	Denotes a player. Used for determining which paddle to draw
	//				and which player score/win to draw. Main purpose is to 
	//				restrict values passed back to the menu on game over, and
	//				to the paddles on game start.
	//////////////////////////////////////////////////////////////////////////
	enum Player{NoOne, P1, P2};

	//////////////////////////////////////////////////////////////////////////
	// Name:		MenuStatus
	// Description:	Holds a MenuState and MenuSelect enum. Encapsulates the 
	//				full state of the menu. Main purpose it to simplify parameters
	//////////////////////////////////////////////////////////////////////////
	struct MenuStatus{
		MenuState state;
		MenuSelect selection;
	};
