#include "FMODAudio.h"
#include <cstdio>
#include <cstdlib>

FMODAudio::FMODAudio()
{

}

FMODAudio::~FMODAudio()
{
	Shutdown();
}

void FMODAudio::Init()
{
	m_Result = FMOD::System_Create(&m_pSystem);
	CheckError(m_Result);

	m_Result = m_pSystem->init(100, FMOD_INIT_NORMAL, 0);
	CheckError(m_Result);

	m_Result = m_pSystem->createSound(BOUNCE_SOUND, FMOD_DEFAULT, 0, & m_pBounceFX);
	CheckError(m_Result);

	m_Result = m_pSystem->createSound(SCROLL_SOUND, FMOD_DEFAULT, 0, & m_pMenuScrollFX);
	CheckError(m_Result);

	m_Result = m_pSystem->createSound(SELECT_SOUND, FMOD_DEFAULT, 0, & m_pMenuSelectFX);
	CheckError(m_Result);

	m_Result = m_pSystem->createSound(GOAL_SOUND, FMOD_DEFAULT, 0, & m_pGoalFX);
	CheckError(m_Result);

	m_Result = m_pSystem->createStream(MENU_SONG, FMOD_LOOP_NORMAL, 0, &m_pMenuBkg);
	CheckError(m_Result);

	m_Result = m_pSystem->createStream(GAME_SONG, FMOD_LOOP_NORMAL, 0, &m_pGameBkg);
	CheckError(m_Result);

	//Preloading the background channel
	m_pSystem->playSound(FMOD_CHANNEL_FREE, m_pMenuBkg, true, &m_pChannelBkg);

}

void FMODAudio::Update()
{
	m_pSystem->update();
}

void FMODAudio::Shutdown()
{
	m_pSystem->release();
}

void FMODAudio::PlayBounceFX()
{
	m_pSystem->playSound(FMOD_CHANNEL_FREE, m_pBounceFX, false, &m_pChannelFX);
}

void FMODAudio::PlayScrollFX()
{
	m_pSystem->playSound(FMOD_CHANNEL_FREE, m_pMenuScrollFX, true, &m_pChannelFX);
	m_pChannelFX->setVolume(0.1f);
	m_pChannelFX->setPaused(false);
}

void FMODAudio::PlaySelectFX()
{
	m_pSystem->playSound(FMOD_CHANNEL_FREE, m_pMenuSelectFX, false, &m_pChannelFX);
}

void FMODAudio::PlayGoalFX()
{
	m_pSystem->playSound(FMOD_CHANNEL_FREE, m_pGoalFX, false, &m_pChannelFX);
}

void FMODAudio::PlayMenuBkg()
{
	if(IsMenuBkgPlaying())
	{
		return;
	}
	else if(IsGameBkgPlaying())
	{
		m_pChannelBkg->stop();
	}
	m_pSystem->playSound(FMOD_CHANNEL_FREE,m_pMenuBkg, false, &m_pChannelBkg);
	m_pChannelBkg->setVolume(0.5f);
}

void FMODAudio::PlayGameBkg()
{
	if(IsGameBkgPlaying())
	{
		return;
	}
	else if(IsMenuBkgPlaying())
	{
		m_pChannelBkg->stop();
	}
	m_pSystem->playSound(FMOD_CHANNEL_FREE,m_pGameBkg, false, &m_pChannelBkg);
	m_pChannelBkg->setVolume(0.5f);
}

void FMODAudio::CheckError(FMOD_RESULT result)
{

	if (result != FMOD_OK)
	{
		printf("FMOD error! (%d) %s\n", result, FMOD_ErrorString(result));
		exit(-1);
	}
}

bool FMODAudio::IsGameBkgPlaying()
{
	bool paused;
	m_pChannelBkg->getPaused(&paused);
	m_pChannelBkg->getCurrentSound(&m_pCurrentSound);
	if((m_pCurrentSound == m_pGameBkg) && (paused == false))
	{
		return true;
	}
	else
	{
	return false;
	}
}

bool FMODAudio::IsMenuBkgPlaying()
{
	bool paused;
	m_pChannelBkg->getPaused(&paused);
	m_pChannelBkg->getCurrentSound(&m_pCurrentSound);
	if((m_pCurrentSound == m_pMenuBkg) && (paused == false))
	{
		return true;
	}
	else
	{
		return false;
	}
}

