#include "GameMenu.h"

GameMenu::GameMenu()
{
	m_Status.selection = MenuSelect::None;
	m_Status.state = MenuState::MenuPaused;
}

GameMenu::~GameMenu()
{

}

void GameMenu::Button_Main()
{
	m_Status.state = MenuState::MainMenu;
	m_Status.selection = MenuSelect::None;
	g_Audio.PlaySelectFX();
}

void GameMenu::Button_Options()
{
	m_Status.state = MenuState::OptionsMenu;
	m_Status.selection = MenuSelect::None;
	g_Audio.PlaySelectFX();
}

void GameMenu::Button_Play()
{
	m_Status.state = MenuState::GameRunning;
	m_Status.selection = MenuSelect::None;
	g_Audio.PlaySelectFX();
}

void GameMenu::Button_Quit()
{
	m_Status.state = MenuState::ExitingGame;
	m_Status.selection = MenuSelect::None;
	g_Audio.PlaySelectFX();
}

void GameMenu::Button_Credits()
{
	m_Status.state = MenuState::Credits;
	m_Status.selection = MenuSelect::None;
	g_Audio.PlaySelectFX();
}

void GameMenu::Button_Fullscreen()
{
	//Toggle fullscreen
}

void GameMenu::Update()
{
	switch(m_Status.state)
	{
	//Do nothing if game running, menu in paused state (before running), or game is about to exit.
	case MenuState::MenuPaused: case MenuState::ExitingGame: case MenuState::GameRunning:
		return;
	//Main Menu: Play, Options, Credits and Quit buttons displayed
	case MenuState::MainMenu:
		switch(m_Status.selection)
		{
		case MenuSelect::None: case MenuSelect::FullscreenButton: case MenuSelect::MainButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::PlayButton;
				g_Audio.PlayScrollFX();
			}
			return;
		case MenuSelect::PlayButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::OptionsButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Play();
			}
			return;
		case MenuSelect::OptionsButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::PlayButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::CreditsButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Options();
			}
			return;
		case MenuSelect::CreditsButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::OptionsButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Credits();
			}
			return;
		case MenuSelect::QuitButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::CreditsButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::PlayButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Quit();
			}
			return;
		}
	//Options menu. Fullscreen Toggle and Main Buttons available.
	case MenuState::OptionsMenu:
		switch(m_Status.selection)
		{
		case MenuSelect::MainButton:
			if(((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP))) || ((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN))))
			{
				m_Status.selection = MenuSelect::FullscreenButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Main();
			}
			return;
		case MenuSelect::FullscreenButton:
			if(((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP))) || ((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN))))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Fullscreen();
			}
			return;
		default:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::FullscreenButton;
				g_Audio.PlayScrollFX();
			}
			return;
		}
	//Credits menu. Only main menu button available.
	case MenuState::Credits:
		if(((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP))) || ((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN))))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
		if((m_Status.selection == MenuSelect::MainButton) && (g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0))))
			{
				Button_Main();
			}
		return;
	//GameOver screen. Only main and quit available.
	case MenuState::GameOver:
		switch(m_Status.selection)
		{
		case MenuSelect::MainButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Main();
			}
			return;
		case MenuSelect::QuitButton:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
			if(g_Input.KeyDown(DIK_RETURN)||(g_Input.MouseButtonDown(0)))
			{
				Button_Quit();
			}
			return;
		default:
			if((g_Input.KeyDown(DIK_UP))&&(!g_Input.WasKeyDown(DIK_UP)))
			{
				m_Status.selection = MenuSelect::QuitButton;
				g_Audio.PlayScrollFX();
			}
			if((g_Input.KeyDown(DIK_DOWN))&&(!g_Input.WasKeyDown(DIK_DOWN)))
			{
				m_Status.selection = MenuSelect::MainButton;
				g_Audio.PlayScrollFX();
			}
			return;
		}
	}
	
}

MenuStatus GameMenu::getStatus()
{
	return m_Status;
}

void GameMenu::GameOver()
{
	m_Status.selection = MenuSelect::None;
	m_Status.state = MenuState::GameOver;
}

void GameMenu::Init()
{
	m_Status.state = MenuState::MainMenu;
	m_Status.selection = MenuSelect::None;
}
