//////////////////////////////////////////////////////////////////////////
// Name:	MainMenu.h
// Date:	January 21st, 2014
// Author:	Tylor Emmett [tsemmett@gmail.com]
// Purpose: This file creates a simple menu system for a game.
//			Provides a startup menu, an options menu, a credits display, 
//			and	a win/loss display
//////////////////////////////////////////////////////////////////////////
#pragma once
#include "Enums.h"
#include "DirectInput.h"
#include "FMODAudio.h"

extern CDirectInputFramework	g_Input;	//Link to input interface.
extern FMODAudio				g_Audio;	//Link to audio intergave.

class GameMenu
{
private:
	//////////////////////////////////////////////////////////////////////////
	// Control structs
	//////////////////////////////////////////////////////////////////////////
	MenuStatus	m_Status;
	bool		m_bMusicPlaying;
		
	//////////////////////////////////////////////////////////////////////////
	// Functions for swapping states based on buttons pressed
	//////////////////////////////////////////////////////////////////////////
	void Button_Main();
	void Button_Options();
	void Button_Play();
	void Button_Quit();
	void Button_Credits();
	void Button_Fullscreen();
	
public:
	//////////////////////////////////////////////////////////////////////////
	//				Default Constructor/Destructor
	//////////////////////////////////////////////////////////////////////////
	GameMenu();
	~GameMenu();

	//////////////////////////////////////////////////////////////////////////
	// Name:		Update
	// Parameters:	none
	// Return:		none
	// Description:	Updates the menu based on last input. 
	//////////////////////////////////////////////////////////////////////////
	void Update();

	//////////////////////////////////////////////////////////////////////////
	// Name:		getStatus
	// Parameters:	none
	// Return:		MenuStatus
	// Description:	Updates the current MenuStatus
	//////////////////////////////////////////////////////////////////////////
	MenuStatus getStatus();
	
	//////////////////////////////////////////////////////////////////////////
	// Name:		GameOver
	// Parameters:	none
	// Return:		none
	// Description:	Restarts menu in GameOver state. Used to return to the menu
	//				after game has been won.
	//////////////////////////////////////////////////////////////////////////
	void GameOver();

	//////////////////////////////////////////////////////////////////////////
	// Name:		Init
	// Parameters:	none
	// Return:		none
	// Description:	Restarts menu in GameOver state. Used to return to the menu
	//				after game has been won.
	//////////////////////////////////////////////////////////////////////////
	void Init();
};
