#include "GameObjects.h"
#include <ctime>

////////////////////////////////////////////////////
//	Contact Function
////////////////////////////////////////////////////
void CheckContactPaddle(Ball* ball, Paddle* paddle)
{
	//Sphere to box contact.
	//Left and right collision
	//Checking first to see if the ball is in the paddle's y range (between the top and bottom)
	if(((ball->m_Position.y + ball->m_Radius) < (paddle->m_Position.y + paddle->m_contactHalfY)) && ((ball->m_Position.y - ball->m_Radius) > (paddle->m_Position.y - paddle->m_contactHalfY)))
	{
		if(paddle->m_Player == Player::P1)
		{
			if((ball->m_Position.x - ball->m_Radius) < (paddle->m_Position.x + paddle->m_contactHalfX))
			{
				ball->Reflect(Axis::X);
				g_Audio.PlayBounceFX();
			}
		}
		if(paddle->m_Player == Player::P2)
		{
			if((ball->m_Position.x + ball->m_Radius) > (paddle->m_Position.x - paddle->m_contactHalfX))
			{
				ball->Reflect(Axis::X);
				g_Audio.PlayBounceFX();
			}

		}
	}
	
}

////////////////////////////////////////////////////
//	Ball Class
////////////////////////////////////////////////////
Ball::Ball(){}

Ball::~Ball(){}

void Ball::Init(D3DXVECTOR3& location, D3DXIMAGE_INFO* imageInfo, RECT window)
{
	m_StartPos = location;
	m_Position = location;
	m_Radius = imageInfo->Width/2.0f * 0.3f; //Scaled down to match render scale.
	m_Velocity = D3DXVECTOR3(0,0,0);
	m_Window = window;
	m_ElapsedTime = 0.0f;
}

void Ball::Update(float dt)
{
	//If ball is not moving (on reset or init), waits 2s then starts ball moving
	if(m_Velocity == D3DXVECTOR3(0,0,0))
	{
		m_ElapsedTime += dt;
		if(m_ElapsedTime >= 2.0f)
		{
			float x, y;
			srand((int)time(0));
			bool isXNegative = (bool)rand()%2;
			bool isYNegative = (bool)rand()%2;
			if(isYNegative)
			{
				y = -450;
			}
			else
			{
				y = 450;
			}
			if(isXNegative)
			{
				x = -450;
			}
			else
			{
				x = 450;
			}
			m_Velocity = D3DXVECTOR3(x, y, 0.0f);
		}
	}
	//Update position based on time and velocity
	m_Position += m_Velocity * dt;
}

void Ball::Reflect(Axis axis)
{
	if(axis == Axis::X)
	{
		m_Velocity.x *= -1;
	}
	else if(axis == Axis::Y)
	{
		m_Velocity.y *= -1;
	}
}

void Ball::Reset()
{
	m_Position = m_StartPos;
	m_Velocity = D3DXVECTOR3(0,0,0);
	m_ElapsedTime = 0.0f;
}

Player Ball::CheckContactWall()
{
	if((m_Position.y - m_Radius < m_Window.top) || (m_Position.y + m_Radius > m_Window.bottom))
	{
		Reflect(Axis::Y);
		g_Audio.PlayBounceFX();
		return Player::NoOne;
	}

	if(m_Position.x - m_Radius < m_Window.left)
	{
		return Player::P2;
	}
	if(m_Position.x + m_Radius > m_Window.right)
	{
		return Player::P1;
	}
	return Player::NoOne;
		
}

D3DXVECTOR3 Ball::getPosition()
{
	return m_Position;
}

////////////////////////////////////////////////////
//	Paddle Class
////////////////////////////////////////////////////
Paddle::Paddle()
{

}

Paddle::~Paddle()
{
	
}

void Paddle::Init(D3DXVECTOR3& location, D3DXIMAGE_INFO* imageInfo,  Player player, RECT window)
{
	m_Player = player;
	m_Velocity = 0;
	m_MaxVelocity = 600;
	m_StartPos = location;
	m_Position = location;
	m_contactHalfX = imageInfo->Width/2.0f * 0.3f;  //Muliplied by 0.3f to match render scale
	m_contactHalfY = imageInfo->Height/2.0f * 0.6f; //Multiplied by 0.6f to match render scale 
	m_Window = window;
}

void Paddle::Reset()
{
	m_Position = m_StartPos;
	m_Velocity = 0;
}

void Paddle::Update(float dt)
{
	//Checking for input. 
	//Player 1, W moves up, S moves down. No input stops the paddle.
	if(m_Player == Player::P1)
	{
		if(g_Input.KeyDown(DIK_W))
			m_Velocity -= 15;
		else if(g_Input.KeyDown(DIK_S))
			m_Velocity += 15;
		else
			m_Velocity = 0;
	}
	//Player 2, Up arrow moves up, Down arrow moves down. No input stops the paddle.
	if(m_Player == Player::P2)
	{
		if(g_Input.KeyDown(DIK_UP))
			m_Velocity -= 15;
		else if(g_Input.KeyDown(DIK_DOWN))
			m_Velocity += 15;
		else
			m_Velocity = 0;
	}

	//Cap velocity to max
	if(m_Velocity > m_MaxVelocity)
	{
		m_Velocity = m_MaxVelocity;
	}
	if(m_Velocity < -m_MaxVelocity)
	{
		m_Velocity = -m_MaxVelocity;
	}

	//Update position by velocity and time.
	m_Position.y += m_Velocity * dt;

	//Clamp to window size
	if(m_Position.y < (m_Window.top + m_contactHalfY))
	{
		m_Position.y = m_Window.top + m_contactHalfY;
	}
	else if(m_Position.y > (m_Window.bottom - m_contactHalfY * 1.35)) //Increased Y half to keep paddle from going slightly below screen.
		m_Position.y = (float)(m_Window.bottom - m_contactHalfY * 1.35);
}

Player Paddle::getPlayer()
{
	return m_Player;
}

D3DXVECTOR3 Paddle::getPosition()
{
	return m_Position;
}




